@@ -26,8 +26,8 @@ const bt::Uint32 WANT_BOTH = WANT_IPV4 | WANT_IPV6;
 /*!
  * \author Joris Guisson
  *
- * A Node represents us in the kademlia network. It contains
- * our id and 160 KBucket's.
+ * \brief Represents us in the kademlia network. It contains our id and 160 KBucket's.
+ *
  * A KBucketEntry is in node i, when the difference between our id and
  * the KBucketEntry's id is between 2 to the power i and 2 to the power i+1.
  */
@@ -63,7 +63,7 @@ public:
     /*!
      * Increase the failed queries count of the bucket entry we sent the message to
      */
-    void onTimeout(RPCMsg::Ptr msg);
+    void onTimeout(const RPCMsg &msg);
 
     //! Check if a buckets needs to be refreshed, and refresh if necesarry
     void refreshBuckets(DHT *dh_table);
@@ -84,7 +84,7 @@ private:
     class Private;
     std::unique_ptr<Private> d;
     dht::Key our_id;
-    bt::Uint32 num_entries;
+    bt::Uint32 num_entries = 0;
 };
 
 }
