@@ -12,7 +12,7 @@
 namespace dht
 {
 /*!
- * Ping response message in the DHT protocol
+ * \brief Ping response message in the DHT protocol.
  */
 class KTORRENT_EXPORT PingRsp : public RPCMsg
 {
@@ -24,8 +24,6 @@ public:
     void apply(DHT *dh_table) override;
     void print() override;
     void encode(QByteArray &arr) const override;
-
-    typedef QSharedPointer<PingRsp> Ptr;
 };
 }
 
