@@ -13,9 +13,8 @@ namespace bt
 {
 /*!
  * \author Joris Guisson
- * \brief Map of pointers
+ * \brief Map of pointers with an optional auto-delete feature.
  *
- * A Map where the data is a pointer. The PtrMap has an autodeletion feature.
  * When autodelete is on, every time we remove something from the map, the data
  * will be deleted.
  */
@@ -86,7 +85,7 @@ public:
     void clear()
     {
         if (autodel) {
-            for (iterator i = pmap.begin(); i != pmap.end(); i++) {
+            for (iterator i = pmap.begin(); i != pmap.end(); ++i) {
                 delete i->second;
                 i->second = nullptr;
             }
@@ -176,7 +175,7 @@ public:
     iterator erase(iterator i)
     {
         iterator j = i;
-        j++;
+        ++j;
         pmap.erase(i);
         return j;
     }
