@@ -13,11 +13,13 @@
 #include <net/poll.h>
 #include <utp/connection.h>
 
+#include <memory>
+
 namespace utp
 {
-/**
-    Implements the UTP server. It listens for UTP packets and manages all connections.
-*/
+/*!
+ * \brief A UTP server that listens for UTP packets and manages all connections.
+ */
 class KTORRENT_EXPORT UTPServer : public bt::ServerInterface, public Transmitter
 {
     Q_OBJECT
@@ -25,36 +27,36 @@ public:
     UTPServer(QObject *parent = nullptr);
     ~UTPServer() override;
 
-    /// Enabled creating sockets (tests need to have this disabled)
+    //! Enabled creating sockets (tests need to have this disabled)
     void setCreateSockets(bool on);
 
     bool changePort(bt::Uint16 port) override;
 
-    /// Send a packet to some host
+    //! Send a packet to some host
     bool sendTo(Connection::Ptr conn, const PacketBuffer &packet) override;
 
-    /// Setup a connection to a remote address
+    //! Setup a connection to a remote address
     Connection::WPtr connectTo(const net::Address &addr);
 
-    /// Get the last accepted connection (Note: for unittest purposes)
+    //! Get the last accepted connection (Note: for unittest purposes)
     Connection::WPtr acceptedConnection();
 
-    /// Start the UTP server
+    //! Start the UTP server
     void start();
 
-    /// Stop the UTP server
+    //! Stop the UTP server
     void stop();
 
-    /// Prepare the server for polling
+    //! Prepare the server for polling
     void preparePolling(net::Poll *p, net::Poll::Mode mode, Connection::Ptr &conn);
 
-    /// Set the TOS byte
+    //! Set the TOS byte
     void setTOS(bt::Uint8 type_of_service);
 
-    /// Thread has been started
+    //! Thread has been started
     void threadStarted();
 
-    /**
+    /*!
         Handle newly connected sockets, it starts authentication on them.
         This needs to be called from the main thread.
     */
@@ -68,7 +70,7 @@ protected:
 
 Q_SIGNALS:
     void handlePendingConnectionsDelayed();
-    /// Emitted when a connection is accepted if creating sockets is disabled
+    //! Emitted when a connection is accepted if creating sockets is disabled
     void accepted();
 
 private:
@@ -77,7 +79,7 @@ private:
 
 private:
     class Private;
-    Private *d;
+    std::unique_ptr<Private> d;
 };
 
 }
